@@ -72,11 +72,12 @@
 #define yynerrs         mimosa_http_request_nerrs
 
 /* First part of user prologue.  */
-#line 12 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 15 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
 
-#include <stdio.h>
+#include <cstdio>
 #include <utility>
 #include <string>
+#include <cstdint>
 
 #include "request.hh"
 #include "request-parser.hh"
@@ -91,7 +92,7 @@
   }
 
 
-#line 95 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 96 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -170,20 +171,22 @@ enum yysymbol_kind_t
   YYSYMBOL_DEFLATE = 48,                   /* DEFLATE  */
   YYSYMBOL_GZIP = 49,                      /* GZIP  */
   YYSYMBOL_SDCH = 50,                      /* SDCH  */
-  YYSYMBOL_51_ = 51,                       /* '='  */
-  YYSYMBOL_52_ = 52,                       /* ';'  */
-  YYSYMBOL_53_ = 53,                       /* ','  */
-  YYSYMBOL_54_ = 54,                       /* '-'  */
-  YYSYMBOL_YYACCEPT = 55,                  /* $accept  */
-  YYSYMBOL_request = 56,                   /* request  */
-  YYSYMBOL_method = 57,                    /* method  */
-  YYSYMBOL_kvs = 58,                       /* kvs  */
-  YYSYMBOL_kv = 59,                        /* kv  */
-  YYSYMBOL_accept_encodings = 60,          /* accept_encodings  */
-  YYSYMBOL_cookies = 61,                   /* cookies  */
-  YYSYMBOL_cookie = 62,                    /* cookie  */
-  YYSYMBOL_byte_range_set = 63,            /* byte_range_set  */
-  YYSYMBOL_byte_range = 64                 /* byte_range  */
+  YYSYMBOL_ZSTD = 51,                      /* ZSTD  */
+  YYSYMBOL_BR = 52,                        /* BR  */
+  YYSYMBOL_53_ = 53,                       /* '='  */
+  YYSYMBOL_54_ = 54,                       /* ';'  */
+  YYSYMBOL_55_ = 55,                       /* ','  */
+  YYSYMBOL_56_ = 56,                       /* '-'  */
+  YYSYMBOL_YYACCEPT = 57,                  /* $accept  */
+  YYSYMBOL_request = 58,                   /* request  */
+  YYSYMBOL_method = 59,                    /* method  */
+  YYSYMBOL_kvs = 60,                       /* kvs  */
+  YYSYMBOL_kv = 61,                        /* kv  */
+  YYSYMBOL_accept_encodings = 62,          /* accept_encodings  */
+  YYSYMBOL_cookies = 63,                   /* cookies  */
+  YYSYMBOL_cookie = 64,                    /* cookie  */
+  YYSYMBOL_byte_range_set = 65,            /* byte_range_set  */
+  YYSYMBOL_byte_range = 66                 /* byte_range  */
 };
 typedef enum yysymbol_kind_t yysymbol_kind_t;
 
@@ -511,19 +514,19 @@ union yyalloc
 /* YYFINAL -- State number of the termination state.  */
 #define YYFINAL  20
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   83
+#define YYLAST   78
 
 /* YYNTOKENS -- Number of terminals.  */
-#define YYNTOKENS  55
+#define YYNTOKENS  57
 /* YYNNTS -- Number of nonterminals.  */
 #define YYNNTS  10
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  52
+#define YYNRULES  54
 /* YYNSTATES -- Number of states.  */
-#define YYNSTATES  83
+#define YYNSTATES  87
 
 /* YYMAXUTOK -- Last valid token kind.  */
-#define YYMAXUTOK   305
+#define YYMAXUTOK   307
 
 
 /* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
@@ -541,9 +544,9 @@ static const yytype_int8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-       2,     2,     2,     2,    53,    54,     2,     2,     2,     2,
-       2,     2,     2,     2,     2,     2,     2,     2,     2,    52,
-       2,    51,     2,     2,     2,     2,     2,     2,     2,     2,
+       2,     2,     2,     2,    55,    56,     2,     2,     2,     2,
+       2,     2,     2,     2,     2,     2,     2,     2,     2,    54,
+       2,    53,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -567,19 +570,19 @@ static const yytype_int8 yytranslate[] =
       15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
       25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
       35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
-      45,    46,    47,    48,    49,    50
+      45,    46,    47,    48,    49,    50,    51,    52
 };
 
 #if YYDEBUG
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    71,    71,    77,    78,    79,    80,    81,    82,    83,
-      84,    85,    86,    87,    88,    89,    90,    91,    92,    93,
-      95,    95,    98,    99,   100,   101,   102,   103,   104,   105,
-     106,   107,   108,   109,   110,   113,   115,   116,   117,   118,
-     119,   120,   122,   124,   125,   128,   129,   130,   133,   134,
-     137,   143,   149
+       0,    75,    75,    81,    82,    83,    84,    85,    86,    87,
+      88,    89,    90,    91,    92,    93,    94,    95,    96,    97,
+      99,    99,   102,   103,   104,   105,   106,   107,   108,   109,
+     110,   111,   112,   113,   116,   117,   119,   120,   121,   122,
+     123,   124,   125,   126,   128,   130,   131,   134,   135,   136,
+     139,   140,   143,   149,   155
 };
 #endif
 
@@ -604,9 +607,10 @@ static const char *const yytname[] =
   "KEY_HOST", "KEY_REFERRER", "KEY_USER_AGENT", "KEY_IF_MODIFIED_SINCE",
   "KEY_DESTINATION", "KEY_RANGE", "VALUE", "HOST", "VALUE_CONNECTION",
   "PORT", "VAL64", "RANGE_UNIT", "RANGE_START", "RANGE_END",
-  "RANGE_LENGTH", "COMPRESS", "IDENTITY", "DEFLATE", "GZIP", "SDCH", "'='",
-  "';'", "','", "'-'", "$accept", "request", "method", "kvs", "kv",
-  "accept_encodings", "cookies", "cookie", "byte_range_set", "byte_range", YY_NULLPTR
+  "RANGE_LENGTH", "COMPRESS", "IDENTITY", "DEFLATE", "GZIP", "SDCH",
+  "ZSTD", "BR", "'='", "';'", "','", "'-'", "$accept", "request", "method",
+  "kvs", "kv", "accept_encodings", "cookies", "cookie", "byte_range_set",
+  "byte_range", YY_NULLPTR
 };
 
 static const char *
@@ -616,7 +620,7 @@ yysymbol_name (yysymbol_kind_t yysymbol)
 }
 #endif
 
-#define YYPACT_NINF (-24)
+#define YYPACT_NINF (-25)
 
 #define yypact_value_is_default(Yyn) \
   ((Yyn) == YYPACT_NINF)
@@ -630,15 +634,15 @@ yysymbol_name (yysymbol_kind_t yysymbol)
    STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
-      -3,   -24,   -24,   -24,   -24,   -24,   -24,   -24,   -24,   -24,
-     -24,   -24,   -24,   -24,   -24,   -24,   -24,   -24,    37,    23,
-     -24,    24,    22,    -6,     9,   -14,     8,    25,     6,    10,
-      13,    14,    16,    17,    18,    19,    15,   -24,    -6,   -24,
-     -14,   -14,   -14,   -14,   -14,   -24,   -24,     7,   -24,    11,
-      21,   -24,   -24,    20,   -24,   -24,   -24,   -24,    26,   -24,
-     -24,   -24,   -24,   -24,   -24,    28,    25,    27,   -24,   -23,
-     -24,   -24,    29,     5,    31,   -24,    30,   -24,    32,   -24,
-     -23,   -24,   -24
+      -3,   -25,   -25,   -25,   -25,   -25,   -25,   -25,   -25,   -25,
+     -25,   -25,   -25,   -25,   -25,   -25,   -25,   -25,    19,    27,
+     -25,    28,    26,    -5,    13,   -13,    12,    29,    10,    14,
+      17,    18,    20,    21,    22,    23,    24,   -25,    -5,   -25,
+     -13,   -13,   -13,   -13,   -13,   -13,   -13,   -25,   -25,     8,
+     -25,     9,    25,   -25,   -25,    30,   -25,   -25,   -25,   -25,
+      11,   -25,   -25,   -25,   -25,   -25,   -25,   -25,   -25,    32,
+      29,    31,   -25,   -24,   -25,   -25,    33,     6,    35,   -25,
+      16,   -25,    36,   -25,   -24,   -25,   -25
 };
 
 /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
@@ -648,25 +652,25 @@ static const yytype_int8 yydefact[] =
 {
        0,     3,     4,     5,     6,     7,     8,     9,    10,    11,
       12,    13,    14,    15,    16,    17,    18,    19,     0,     0,
-       1,     0,     0,    21,     0,    36,     0,    42,     0,     0,
-       0,     0,     0,     0,     0,     0,     0,     2,    21,    22,
-      36,    36,    36,    36,    36,    23,    24,    45,    25,    43,
-       0,    26,    27,    29,    30,    31,    32,    33,     0,    20,
-      37,    38,    39,    40,    41,    46,    42,     0,    28,     0,
-      47,    44,     0,     0,     0,    35,    48,    34,    51,    52,
-       0,    50,    49
+       1,     0,     0,    21,     0,    36,     0,    44,     0,     0,
+       0,     0,     0,     0,     0,     0,     0,     2,    21,    35,
+      36,    36,    36,    36,    36,    36,    36,    22,    23,    47,
+      24,    45,     0,    25,    26,    28,    29,    30,    31,    32,
+       0,    20,    37,    38,    39,    40,    43,    41,    42,    48,
+      44,     0,    27,     0,    49,    46,     0,     0,     0,    34,
+      50,    33,    53,    54,     0,    52,    51
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-     -24,   -24,   -24,    38,   -24,    -2,    -5,   -24,   -18,   -24
+     -25,   -25,   -25,    34,   -25,     0,     3,   -25,   -19,   -25
 };
 
 /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-       0,    18,    19,    37,    38,    45,    48,    49,    75,    76
+       0,    18,    19,    37,    38,    47,    50,    51,    79,    80
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
@@ -675,27 +679,25 @@ static const yytype_int8 yydefgoto[] =
 static const yytype_int8 yytable[] =
 {
        1,     2,     3,     4,     5,     6,     7,     8,     9,    10,
-      11,    12,    13,    14,    15,    16,    17,    24,    73,    25,
-      26,    27,    28,    29,    30,    31,    32,    33,    34,    35,
-      36,    74,    40,    41,    42,    43,    44,    20,    60,    61,
-      62,    63,    64,    21,    23,    22,    39,    46,    50,    47,
-      52,    51,    53,    54,    55,    56,    57,    58,    65,    78,
-      68,    71,    82,    66,    67,    70,     0,     0,     0,     0,
-       0,    72,    79,    81,    77,     0,    59,    69,     0,     0,
-       0,     0,     0,    80
+      11,    12,    13,    14,    15,    16,    17,    77,    24,    20,
+      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
+      35,    36,    78,    40,    41,    42,    43,    44,    45,    46,
+      62,    63,    64,    65,    66,    67,    68,    21,    23,    22,
+      39,    48,    52,    49,    54,    53,    55,    56,    57,    58,
+      59,    69,    82,    70,    73,    86,    60,     0,    71,    74,
+      72,    84,    61,    75,     0,    76,    83,    85,    81
 };
 
 static const yytype_int8 yycheck[] =
 {
        3,     4,     5,     6,     7,     8,     9,    10,    11,    12,
-      13,    14,    15,    16,    17,    18,    19,    23,    41,    25,
-      26,    27,    28,    29,    30,    31,    32,    33,    34,    35,
-      36,    54,    46,    47,    48,    49,    50,     0,    40,    41,
-      42,    43,    44,    20,    22,    21,    37,    39,    42,    24,
-      37,    41,    38,    37,    37,    37,    37,    42,    51,    54,
-      40,    66,    80,    52,    43,    37,    -1,    -1,    -1,    -1,
-      -1,    44,    41,    41,    45,    -1,    38,    51,    -1,    -1,
-      -1,    -1,    -1,    53
+      13,    14,    15,    16,    17,    18,    19,    41,    23,     0,
+      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
+      35,    36,    56,    46,    47,    48,    49,    50,    51,    52,
+      40,    41,    42,    43,    44,    45,    46,    20,    22,    21,
+      37,    39,    42,    24,    37,    41,    38,    37,    37,    37,
+      37,    53,    56,    54,    53,    84,    42,    -1,    43,    37,
+      40,    55,    38,    70,    -1,    44,    41,    41,    45
 };
 
 /* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
@@ -703,25 +705,25 @@ static const yytype_int8 yycheck[] =
 static const yytype_int8 yystos[] =
 {
        0,     3,     4,     5,     6,     7,     8,     9,    10,    11,
-      12,    13,    14,    15,    16,    17,    18,    19,    56,    57,
+      12,    13,    14,    15,    16,    17,    18,    19,    58,    59,
        0,    20,    21,    22,    23,    25,    26,    27,    28,    29,
-      30,    31,    32,    33,    34,    35,    36,    58,    59,    37,
-      46,    47,    48,    49,    50,    60,    39,    24,    61,    62,
-      42,    41,    37,    38,    37,    37,    37,    37,    42,    58,
-      60,    60,    60,    60,    60,    51,    52,    43,    40,    51,
-      37,    61,    44,    41,    54,    63,    64,    45,    54,    41,
-      53,    41,    63
+      30,    31,    32,    33,    34,    35,    36,    60,    61,    37,
+      46,    47,    48,    49,    50,    51,    52,    62,    39,    24,
+      63,    64,    42,    41,    37,    38,    37,    37,    37,    37,
+      42,    60,    62,    62,    62,    62,    62,    62,    62,    53,
+      54,    43,    40,    53,    37,    63,    44,    41,    56,    65,
+      66,    45,    56,    41,    55,    41,    65
 };
 
 /* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
 static const yytype_int8 yyr1[] =
 {
-       0,    55,    56,    57,    57,    57,    57,    57,    57,    57,
-      57,    57,    57,    57,    57,    57,    57,    57,    57,    57,
-      58,    58,    59,    59,    59,    59,    59,    59,    59,    59,
-      59,    59,    59,    59,    59,    59,    60,    60,    60,    60,
-      60,    60,    61,    61,    61,    62,    62,    62,    63,    63,
-      64,    64,    64
+       0,    57,    58,    59,    59,    59,    59,    59,    59,    59,
+      59,    59,    59,    59,    59,    59,    59,    59,    59,    59,
+      60,    60,    61,    61,    61,    61,    61,    61,    61,    61,
+      61,    61,    61,    61,    61,    61,    62,    62,    62,    62,
+      62,    62,    62,    62,    63,    63,    63,    64,    64,    64,
+      65,    65,    66,    66,    66
 };
 
 /* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
@@ -729,10 +731,10 @@ static const yytype_int8 yyr2[] =
 {
        0,     2,     5,     1,     1,     1,     1,     1,     1,     1,
        1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
-       2,     0,     2,     2,     2,     2,     2,     2,     3,     2,
-       2,     2,     2,     2,     5,     4,     0,     2,     2,     2,
-       2,     2,     0,     1,     3,     1,     2,     3,     1,     3,
-       3,     2,     2
+       2,     0,     2,     2,     2,     2,     2,     3,     2,     2,
+       2,     2,     2,     5,     4,     2,     0,     2,     2,     2,
+       2,     2,     2,     2,     0,     1,     3,     1,     2,     3,
+       1,     3,     3,     2,     2
 };
 
 
@@ -1207,33 +1209,33 @@ yydestruct (const char *yymsg,
   switch (yykind)
     {
     case YYSYMBOL_LOCATION: /* LOCATION  */
-#line 67 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 71 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
             { delete ((*yyvaluep).text); }
-#line 1213 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1215 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
         break;
 
     case YYSYMBOL_KEY: /* KEY  */
-#line 67 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 71 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
             { delete ((*yyvaluep).text); }
-#line 1219 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1221 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
         break;
 
     case YYSYMBOL_ATTR: /* ATTR  */
-#line 67 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 71 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
             { delete ((*yyvaluep).text); }
-#line 1225 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1227 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
         break;
 
     case YYSYMBOL_VALUE: /* VALUE  */
-#line 67 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 71 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
             { delete ((*yyvaluep).text); }
-#line 1231 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1233 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
         break;
 
     case YYSYMBOL_HOST: /* HOST  */
-#line 67 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 71 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
             { delete ((*yyvaluep).text); }
-#line 1237 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1239 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
         break;
 
       default:
@@ -1510,234 +1512,246 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* request: method LOCATION PROTO_MAJOR PROTO_MINOR kvs  */
-#line 71 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 75 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                                                      {
   rq.setRawLocation(std::move(*(yyvsp[-3].text))); delete (yyvsp[-3].text);
   rq.setProto((yyvsp[-2].ival), (yyvsp[-1].ival));
 }
-#line 1519 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1521 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 3: /* method: HEAD  */
-#line 77 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 81 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodHead); }
-#line 1525 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1527 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 4: /* method: GET  */
-#line 78 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 82 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodGet); }
-#line 1531 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1533 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 5: /* method: POST  */
-#line 79 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 83 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodPost); }
-#line 1537 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1539 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 6: /* method: PUT  */
-#line 80 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 84 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodPut); }
-#line 1543 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1545 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 7: /* method: DELETE  */
-#line 81 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 85 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodDelete); }
-#line 1549 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1551 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 8: /* method: TRACE  */
-#line 82 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 86 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodTrace); }
-#line 1555 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1557 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 9: /* method: OPTIONS  */
-#line 83 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 87 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodOptions); }
-#line 1561 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1563 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 10: /* method: CONNECT  */
-#line 84 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 88 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodConnect); }
-#line 1567 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1569 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 11: /* method: PATCH  */
-#line 85 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 89 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
           { rq.setMethod(mimosa::http::kMethodPatch); }
-#line 1573 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1575 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 12: /* method: PROPFIND  */
-#line 86 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 90 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
            { rq.setMethod(mimosa::http::kMethodPropfind); }
-#line 1579 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1581 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 13: /* method: PROPPATCH  */
-#line 87 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 91 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
             { rq.setMethod(mimosa::http::kMethodProppatch); }
-#line 1585 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1587 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 14: /* method: MKCOL  */
-#line 88 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 92 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
         { rq.setMethod(mimosa::http::kMethodMkcol); }
-#line 1591 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1593 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 15: /* method: COPY  */
-#line 89 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 93 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
        { rq.setMethod(mimosa::http::kMethodCopy); }
-#line 1597 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1599 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 16: /* method: MOVE  */
-#line 90 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 94 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
        { rq.setMethod(mimosa::http::kMethodMove); }
-#line 1603 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1605 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 17: /* method: LOCK  */
-#line 91 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 95 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
        { rq.setMethod(mimosa::http::kMethodLock); }
-#line 1609 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1611 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 18: /* method: UNLOCK  */
-#line 92 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 96 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
          { rq.setMethod(mimosa::http::kMethodUnlock); }
-#line 1615 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1617 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 19: /* method: MIMOSA_SYMLINK  */
-#line 93 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 97 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                  { rq.setMethod(mimosa::http::kMethodMimosaSymlink); }
-#line 1621 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1623 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 22: /* kv: KEY VALUE  */
-#line 98 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-            { rq.addHeader(*(yyvsp[-1].text), *(yyvsp[0].text)); delete (yyvsp[-1].text); delete (yyvsp[0].text); }
-#line 1627 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
-    break;
-
-  case 24: /* kv: KEY_CONNECTION VALUE_CONNECTION  */
-#line 100 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                                  { rq.setKeepAlive((yyvsp[0].ival)); }
-#line 1633 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
-    break;
-
-  case 26: /* kv: KEY_CONTENT_LENGTH VAL64  */
-#line 102 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                           { rq.setContentLength((yyvsp[0].val64)); }
-#line 1639 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
-    break;
-
-  case 27: /* kv: KEY_CONTENT_TYPE VALUE  */
+  case 23: /* kv: KEY_CONNECTION VALUE_CONNECTION  */
 #line 103 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                         { rq.setContentType(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
-#line 1645 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+                                  { rq.setKeepAlive((yyvsp[0].ival)); }
+#line 1629 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 28: /* kv: KEY_HOST HOST PORT  */
-#line 104 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                     { rq.setHost(std::move(*(yyvsp[-1].text))); delete (yyvsp[-1].text); rq.setPort((yyvsp[0].ival)); }
-#line 1651 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
-    break;
-
-  case 29: /* kv: KEY_HOST HOST  */
+  case 25: /* kv: KEY_CONTENT_LENGTH VAL64  */
 #line 105 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                { rq.setHost(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
-#line 1657 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+                           { rq.setContentLength((yyvsp[0].val64)); }
+#line 1635 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 30: /* kv: KEY_REFERRER VALUE  */
+  case 26: /* kv: KEY_CONTENT_TYPE VALUE  */
 #line 106 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                     { rq.setReferrer(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
-#line 1663 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+                         { rq.setContentType(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
+#line 1641 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 31: /* kv: KEY_USER_AGENT VALUE  */
+  case 27: /* kv: KEY_HOST HOST PORT  */
 #line 107 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                       { rq.setUserAgent(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
-#line 1669 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+                     { rq.setHost(std::move(*(yyvsp[-1].text))); delete (yyvsp[-1].text); rq.setPort((yyvsp[0].ival)); }
+#line 1647 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 32: /* kv: KEY_IF_MODIFIED_SINCE VALUE  */
+  case 28: /* kv: KEY_HOST HOST  */
 #line 108 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                              { rq.parseIfModifiedSince(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
-#line 1675 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+                { rq.setHost(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
+#line 1653 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 33: /* kv: KEY_DESTINATION VALUE  */
+  case 29: /* kv: KEY_REFERRER VALUE  */
 #line 109 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
-                        { rq.setDestination(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
-#line 1681 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+                     { rq.setReferrer(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
+#line 1659 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 34: /* kv: KEY_CONTENT_RANGE RANGE_UNIT RANGE_START RANGE_END RANGE_LENGTH  */
+  case 30: /* kv: KEY_USER_AGENT VALUE  */
 #line 110 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+                       { rq.setUserAgent(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
+#line 1665 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+    break;
+
+  case 31: /* kv: KEY_IF_MODIFIED_SINCE VALUE  */
+#line 111 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+                              { rq.parseIfModifiedSince(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
+#line 1671 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+    break;
+
+  case 32: /* kv: KEY_DESTINATION VALUE  */
+#line 112 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+                        { rq.setDestination(std::move(*(yyvsp[0].text))); delete (yyvsp[0].text); }
+#line 1677 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+    break;
+
+  case 33: /* kv: KEY_CONTENT_RANGE RANGE_UNIT RANGE_START RANGE_END RANGE_LENGTH  */
+#line 113 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                                                                   {
     rq.setContentRange((yyvsp[-3].val64) * (yyvsp[-2].val64), (yyvsp[-3].val64) * (yyvsp[-1].val64), (yyvsp[-3].val64) * (yyvsp[0].val64));
 }
-#line 1689 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1685 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+    break;
+
+  case 35: /* kv: KEY VALUE  */
+#line 117 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+            { rq.addHeader(*(yyvsp[-1].text), *(yyvsp[0].text)); delete (yyvsp[-1].text); delete (yyvsp[0].text); }
+#line 1691 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 37: /* accept_encodings: COMPRESS accept_encodings  */
-#line 116 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 120 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                             { rq.setAcceptEncoding(rq.acceptEncoding() | mimosa::http::kCodingCompress); }
-#line 1695 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1697 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 38: /* accept_encodings: IDENTITY accept_encodings  */
-#line 117 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 121 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                             { rq.setAcceptEncoding(rq.acceptEncoding() | mimosa::http::kCodingIdentity); }
-#line 1701 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1703 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 39: /* accept_encodings: DEFLATE accept_encodings  */
-#line 118 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 122 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                             { rq.setAcceptEncoding(rq.acceptEncoding() | mimosa::http::kCodingDeflate); }
-#line 1707 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1709 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
   case 40: /* accept_encodings: GZIP accept_encodings  */
-#line 119 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 123 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                             { rq.setAcceptEncoding(rq.acceptEncoding() | mimosa::http::kCodingGzip); }
-#line 1713 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1715 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 41: /* accept_encodings: SDCH accept_encodings  */
-#line 120 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+  case 41: /* accept_encodings: ZSTD accept_encodings  */
+#line 124 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+                            { rq.setAcceptEncoding(rq.acceptEncoding() | mimosa::http::kCodingZstd); }
+#line 1721 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+    break;
+
+  case 42: /* accept_encodings: BR accept_encodings  */
+#line 125 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+                            { rq.setAcceptEncoding(rq.acceptEncoding() | mimosa::http::kCodingBr); }
+#line 1727 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+    break;
+
+  case 43: /* accept_encodings: SDCH accept_encodings  */
+#line 126 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                             { rq.setAcceptEncoding(rq.acceptEncoding() | mimosa::http::kCodingSdch); }
-#line 1719 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1733 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 45: /* cookie: ATTR  */
-#line 128 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+  case 47: /* cookie: ATTR  */
+#line 134 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
      { rq.addCookie(*(yyvsp[0].text), ""); delete (yyvsp[0].text); }
-#line 1725 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1739 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 46: /* cookie: ATTR '='  */
-#line 129 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+  case 48: /* cookie: ATTR '='  */
+#line 135 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
            { rq.addCookie(*(yyvsp[-1].text), ""); delete (yyvsp[-1].text); }
-#line 1731 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1745 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 47: /* cookie: ATTR '=' VALUE  */
-#line 130 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+  case 49: /* cookie: ATTR '=' VALUE  */
+#line 136 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                  { rq.addCookie(*(yyvsp[-2].text), *(yyvsp[0].text)); delete (yyvsp[-2].text); delete (yyvsp[0].text); }
-#line 1737 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1751 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 50: /* byte_range: VAL64 '-' VAL64  */
-#line 137 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+  case 52: /* byte_range: VAL64 '-' VAL64  */
+#line 143 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
                 {
   mimosa::http::ByteRange br;
   br.type_  = mimosa::http::ByteRange::kRange;
@@ -1745,11 +1759,11 @@ yyreduce:
   br.end_   = (yyvsp[0].val64);
   rq.addRange(br);
 }
-#line 1749 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1763 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 51: /* byte_range: VAL64 '-'  */
-#line 143 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+  case 53: /* byte_range: VAL64 '-'  */
+#line 149 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
               {
   mimosa::http::ByteRange br;
   br.type_  = mimosa::http::ByteRange::kStart;
@@ -1757,11 +1771,11 @@ yyreduce:
   br.end_   = 0;
   rq.addRange(br);
 }
-#line 1761 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1775 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
-  case 52: /* byte_range: '-' VAL64  */
-#line 149 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+  case 54: /* byte_range: '-' VAL64  */
+#line 155 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
               {
   mimosa::http::ByteRange br;
   br.type_  = mimosa::http::ByteRange::kSuffix;
@@ -1769,11 +1783,11 @@ yyreduce:
   br.end_   = (yyvsp[0].val64);
   rq.addRange(br);
 }
-#line 1773 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1787 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
     break;
 
 
-#line 1777 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
+#line 1791 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.cc"
 
       default: break;
     }
@@ -1997,5 +2011,5 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 157 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
+#line 163 "/build/hefur/src/hefur/mimosa/mimosa/http/request-parser.y"
 
